@@ -8,13 +8,13 @@ from bridger.settings import bridger_settings
 
 def share_action_button(request):
     serializer = bridger_settings.DEFAULT_SHARE_SERIALIZER
-    fields = [field for field in serializer().fields]
+    fields = tuple([field for field in serializer().fields])
 
     btn = ActionButton(
         icon=WBIcon.TRADE.value,
         description_fields="",
         endpoint=reverse("bridger:share", request=request),
-        instance_display=InstanceDisplay(sections=[Section(fields=FieldSet(fields=fields))]),
+        instance_display=InstanceDisplay(sections=tuple([Section(fields=FieldSet(fields=fields))])),
         confirm_config=ButtonConfig(label="Share", icon=WBIcon.TRADE.value),
         serializer=serializer,
     )
