@@ -1,3 +1,4 @@
+
 import pytest
 from bridger.tests.mixins import TestModelClass, TestSerializerClass, TestrepresentationViewSetClass, TestViewSetClass, TestInfViewSetClass
 from bridger.tests.utils import get_all_subclasses, is_intermediate_table_m2m, all_subclasses
@@ -34,21 +35,6 @@ if remote_inf_modelviewsets:
 if len([imvs for imvs in inf_modelviewsets]) == 0:
     inf_modelviewsets = [None]
 
-
-remote_models = get_specfics_module.send(sender = models)
-if remote_models:
-    _, models = remote_models[0]
-remote_serializers = get_specfics_module.send(sender = serializers)
-if remote_serializers:
-    _, serializers = remote_serializers[0]
-remote_representationviewsets = get_specfics_module.send(sender = representationviewsets)
-if remote_representationviewsets:
-    _, representationviewsets = remote_representationviewsets[0]
-remote_modelviewsets = get_specfics_module.send(sender = modelviewsets)
-if remote_modelviewsets:
-    _, modelviewsets = remote_modelviewsets[0]
-
-
 @pytest.mark.django_db 
 class TestProject:
     @pytest.mark.parametrize("model", models)
@@ -65,14 +51,14 @@ class TestProject:
         my_test.execute_test()
 
     @pytest.mark.parametrize("rvs", representationviewsets)
-    def test_representationviewsets(self, rvs, admin_client):
+    def test_representationviewsets(self, rvs):
         my_test = TestrepresentationViewSetClass(rvs)
-        my_test.execute_test(admin_client)
+        my_test.execute_test()
 
     @pytest.mark.parametrize("mvs", modelviewsets)
-    def test_modelviewsets(self, mvs, admin_client):
+    def test_modelviewsets(self, mvs, client):
         my_test = TestViewSetClass(mvs)
-        my_test.execute_test(admin_client)
+        my_test.execute_test(client)
 
     # @pytest.mark.parametrize("imvs", inf_modelviewsets)
     # def test_inf_modelviewsets(self, imvs, admin_client):
